==> zio-aws-rds_2.12-5.17.129.2-sources.jar: zio/aws/rds/model/DescribeCustomAvailabilityZonesRequest.scala <==
package zio.aws.rds.model
import java.lang.Integer
import zio.aws.rds.model.primitives.IntegerOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeCustomAvailabilityZonesRequest(
    customAvailabilityZoneId: scala.Option[String] = None,
    filters: scala.Option[Iterable[zio.aws.rds.model.Filter]] = None,
    maxRecords: scala.Option[IntegerOptional] = None,
    marker: scala.Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DescribeCustomAvailabilityZonesRequest = {
    import DescribeCustomAvailabilityZonesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DescribeCustomAvailabilityZonesRequest
      .builder()
      .optionallyWith(
        customAvailabilityZoneId.map(value => value: java.lang.String)
      )(_.customAvailabilityZoneId)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(
        maxRecords.map(value => IntegerOptional.unwrap(value): Integer)
      )(_.maxRecords)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.DescribeCustomAvailabilityZonesRequest.ReadOnly =
    zio.aws.rds.model.DescribeCustomAvailabilityZonesRequest
      .wrap(buildAwsValue())
}
object DescribeCustomAvailabilityZonesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DescribeCustomAvailabilityZonesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.DescribeCustomAvailabilityZonesRequest =
      zio.aws.rds.model.DescribeCustomAvailabilityZonesRequest(
        customAvailabilityZoneId.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxRecords.map(value => value),
        marker.map(value => value)
      )
    def customAvailabilityZoneId: scala.Option[String]
    def filters: scala.Option[List[zio.aws.rds.model.Filter.ReadOnly]]
    def maxRecords: scala.Option[IntegerOptional]
    def marker: scala.Option[String]
    def getCustomAvailabilityZoneId: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("customAvailabilityZoneId", customAvailabilityZoneId)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.rds.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxRecords: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DescribeCustomAvailabilityZonesRequest
  ) extends zio.aws.rds.model.DescribeCustomAvailabilityZonesRequest.ReadOnly {
    override val customAvailabilityZoneId: scala.Option[String] =
      scala.Option(impl.customAvailabilityZoneId()).map(value => value: String)
    override val filters
        : scala.Option[List[zio.aws.rds.model.Filter.ReadOnly]] = scala
      .Option(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.rds.model.Filter.wrap(item)
        }.toList
      )
    override val maxRecords: scala.Option[IntegerOptional] = scala
      .Option(impl.maxRecords())
      .map(value => zio.aws.rds.model.primitives.IntegerOptional(value))
    override val marker: scala.Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DescribeCustomAvailabilityZonesRequest
  ): zio.aws.rds.model.DescribeCustomAvailabilityZonesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-rds_2.12-5.17.152.1-sources.jar: zio/aws/rds/model/DescribeCustomAvailabilityZonesRequest.scala <==
package zio.aws.rds.model
import java.lang.Integer
import zio.aws.rds.model.primitives.IntegerOptional
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeCustomAvailabilityZonesRequest(
    customAvailabilityZoneId: scala.Option[String] = None,
    filters: scala.Option[Iterable[zio.aws.rds.model.Filter]] = None,
    maxRecords: scala.Option[IntegerOptional] = None,
    marker: scala.Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DescribeCustomAvailabilityZonesRequest = {
    import DescribeCustomAvailabilityZonesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DescribeCustomAvailabilityZonesRequest
      .builder()
      .optionallyWith(
        customAvailabilityZoneId.map(value => value: java.lang.String)
      )(_.customAvailabilityZoneId)
      .optionallyWith(
        filters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.filters)
      .optionallyWith(maxRecords.map(value => value: Integer))(_.maxRecords)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.rds.model.DescribeCustomAvailabilityZonesRequest.ReadOnly =
    zio.aws.rds.model.DescribeCustomAvailabilityZonesRequest
      .wrap(buildAwsValue())
}
object DescribeCustomAvailabilityZonesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DescribeCustomAvailabilityZonesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.DescribeCustomAvailabilityZonesRequest =
      zio.aws.rds.model.DescribeCustomAvailabilityZonesRequest(
        customAvailabilityZoneId.map(value => value),
        filters.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        maxRecords.map(value => value),
        marker.map(value => value)
      )
    def customAvailabilityZoneId: scala.Option[String]
    def filters: scala.Option[List[zio.aws.rds.model.Filter.ReadOnly]]
    def maxRecords: scala.Option[IntegerOptional]
    def marker: scala.Option[String]
    def getCustomAvailabilityZoneId: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("customAvailabilityZoneId", customAvailabilityZoneId)
    def getFilters
        : ZIO[Any, AwsError, List[zio.aws.rds.model.Filter.ReadOnly]] =
      AwsError.unwrapOptionField("filters", filters)
    def getMaxRecords: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DescribeCustomAvailabilityZonesRequest
  ) extends zio.aws.rds.model.DescribeCustomAvailabilityZonesRequest.ReadOnly {
    override val customAvailabilityZoneId: scala.Option[String] =
      scala.Option(impl.customAvailabilityZoneId()).map(value => value: String)
    override val filters
        : scala.Option[List[zio.aws.rds.model.Filter.ReadOnly]] = scala
      .Option(impl.filters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.rds.model.Filter.wrap(item)
        }.toList
      )
    override val maxRecords: scala.Option[IntegerOptional] =
      scala.Option(impl.maxRecords()).map(value => value: IntegerOptional)
    override val marker: scala.Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DescribeCustomAvailabilityZonesRequest
  ): zio.aws.rds.model.DescribeCustomAvailabilityZonesRequest.ReadOnly =
    new Wrapper(impl)
}
